const SUPPORT_IMAGE_TYPE_LIST = ["image/png", "image/jpeg", "image/gif"];
var ImageUploadErrorCodeEnum = /* @__PURE__ */ ((ImageUploadErrorCodeEnum2) => {
  ImageUploadErrorCodeEnum2[ImageUploadErrorCodeEnum2["none"] = 0] = "none";
  ImageUploadErrorCodeEnum2[ImageUploadErrorCodeEnum2["unSupportType"] = 1] = "unSupportType";
  ImageUploadErrorCodeEnum2[ImageUploadErrorCodeEnum2["onlyOne"] = 2] = "onlyOne";
  return ImageUploadErrorCodeEnum2;
})(ImageUploadErrorCodeEnum || {});
const TARGET_IPHONE_VERSION = 13.4;
const checkType = (files) => {
  return files.every((file) => SUPPORT_IMAGE_TYPE_LIST.includes(file.type));
};
const checkUploadRules = (files, isMultiple) => {
  return new Promise((resolve, reject) => {
    const fileLength = files.length;
    if (!isMultiple && fileLength > 1) {
      reject({
        code: 2,
        message: "\u6BCF\u6B21\u53EA\u80FD\u4E0A\u4F20\u4E00\u5F20\u56FE\u7247\uFF0C\u8BF7\u91CD\u65B0\u9009\u62E9"
      });
      return;
    }
    if (!files || fileLength <= 0) {
      reject({
        code: 0,
        message: "\u672A\u83B7\u53D6\u5230\u56FE\u7247\uFF0C\u8BF7\u91CD\u65B0\u9009\u62E9"
      });
      return;
    }
    if (!checkType(files)) {
      reject({
        code: 1,
        message: "\u6587\u4EF6\u7C7B\u578B\u4E0D\u652F\u6301, \u8BF7\u91CD\u65B0\u9009\u62E9"
      });
      return;
    }
    resolve(true);
  });
};
const base64toBlob = (dataurl) => {
  var _a;
  const arr = dataurl.split(",");
  const mime = (_a = arr[0].match(/:(.*?);/)) == null ? void 0 : _a[1];
  const bstr = atob(arr[1]);
  let n = bstr.length;
  const u8arr = new Uint8Array(n);
  while (n--) {
    u8arr[n] = bstr.charCodeAt(n);
  }
  return new Blob([u8arr], { type: mime });
};
const urlToBase64 = (url) => {
  return new Promise((resolve, reject) => {
    import("../../index2.js").then(function(n) {
      return n.i;
    }).then(async (imageConversion) => {
      imageConversion.urltoBlob(url).then((file) => {
        imageConversion.filetoDataURL(file).then((base64Data) => {
          resolve(base64Data);
        }).catch(reject);
      }).catch(reject);
    });
  });
};
const base64ToFile = (base64Data, imgName) => {
  try {
    const blob = base64toBlob(base64Data);
    return new File([blob], imgName);
  } catch (err) {
    console.error(err);
    return null;
  }
};
const getOrientation = (file) => {
  return new Promise((resolve, reject) => {
    const userAgent = window.navigator.userAgent.toLowerCase();
    const uaMatch = userAgent.match(/cpu iphone os (.*?) like mac os/);
    const iosVersion = uaMatch ? uaMatch[1].replace(/^(\d+)_(\d+)\S*/, "$1.$2") : "0";
    if (uaMatch && parseInt(iosVersion, 10) < TARGET_IPHONE_VERSION) {
      try {
        import("../../index2.js").then(function(n) {
          return n.i;
        }).then(async (imageConversion) => {
          var _a;
          const dataURL = (_a = await imageConversion.filetoDataURL(file).catch(reject)) != null ? _a : "";
          const image = await imageConversion.dataURLtoImage(dataURL).catch(reject);
          import("../../exif2.js").then((EXIF) => {
            let orient;
            EXIF.default.getData(image, () => {
              orient = EXIF.default.getTag(image, "Orientation");
              resolve(orient);
            });
          });
        });
      } catch (err) {
        resolve(void 0);
      }
    } else {
      return resolve(void 0);
    }
  });
};
const compressFileToDataURL = (file, size = 500) => {
  return new Promise((resolve, reject) => {
    import("../../index2.js").then(function(n) {
      return n.i;
    }).then(async (imageConversion) => {
      var _a, _b;
      console.time("compressFileToDataURL");
      const orientation = (_a = await getOrientation(file).catch(reject)) != null ? _a : 0;
      const compressFile2 = await imageConversion.compressAccurately(
        file,
        { size, orientation }
      ).catch(reject);
      if (compressFile2) {
        const dataURL = (_b = await imageConversion.filetoDataURL(compressFile2).catch(reject)) != null ? _b : "";
        console.log(
          `%c\u538B\u7F29\u6587\u4EF6\u4E3Abase64 %c${file.size / 1024}KB >>> ${compressFile2.size / 1024}KB`,
          "color:blue",
          "color:green"
        );
        console.timeEnd("compressFileToDataURL");
        resolve({
          dataURL,
          compressFile: compressFile2,
          fileName: file.name,
          fileType: file.type
        });
      }
    });
  });
};
const compressFile = (file, size = 500) => {
  return new Promise((resolve, reject) => {
    import("../../index2.js").then(function(n) {
      return n.i;
    }).then(async (imageConversion) => {
      var _a;
      const orientation = (_a = await getOrientation(file).catch(reject)) != null ? _a : 0;
      const imageFile = await imageConversion.compress(file, { size, orientation }).catch(reject);
      if (imageFile) {
        console.log(
          `%c\u538B\u7F29\u6587\u4EF6 %c${file.size / 1024}KB >>> ${imageFile.size / 1024}KB`,
          "color:blue",
          "color:green"
        );
        resolve(new File([imageFile], file.name));
      }
    });
  });
};
const compressCanvesToFile = (canvasEle, filename = "example.jpg", size = 500) => {
  return new Promise((resolve, reject) => {
    import("../../index2.js").then(function(n) {
      return n.i;
    }).then(async (imageConversion) => {
      console.time("compressFileToDataURL");
      imageConversion.canvastoFile(canvasEle, 0.8).then((file) => {
        imageConversion.compress(file, size).then((imageFile) => {
          console.log(
            `%c\u538B\u7F29\u6587\u4EF6 %c${file.size / 1024}KB >>> ${imageFile.size / 1024}KB`,
            "color:blue",
            "color:green"
          );
          console.timeEnd("compressFileToDataURL");
          resolve(new File([imageFile], filename));
        }).catch(reject);
      }).catch(reject);
    });
  });
};
const compressUploader = async (items) => {
  if (!items) {
    throw Error("\u4E0A\u4F20\u9644\u4EF6\u4E3A\u7A7A");
  }
  let files, isMultiple;
  if (isMultiple = Array.isArray(items)) {
    const uploaderFileList = items;
    if (!uploaderFileList.every((item) => item.file)) {
      throw Error("\u4E0A\u4F20\u9644\u4EF6\u5B58\u5728\u7A7A\u6587\u4EF6");
    }
    files = uploaderFileList.map((item) => item.file);
  } else {
    const uploaderFile = items;
    if (!uploaderFile.file) {
      throw Error("\u4E0A\u4F20\u9644\u4EF6\u4E3A\u7A7A\u6587\u4EF6");
    }
    files = [uploaderFile.file];
  }
  const isChecked = checkUploadRules(files, isMultiple);
  if (!isChecked) {
    throw Error("\u9644\u4EF6\u68C0\u67E5\u65E0\u6548");
  }
  const result = [];
  for (const file of files) {
    const imageData = await compressFileToDataURL(file).catch(Promise.reject);
    result.push(imageData);
  }
  return result;
};
const getImageData = (e, isMultiple = false) => {
  const target = e.target;
  const result = [];
  const files = Array.prototype.slice.call(target.files);
  const fileLength = files.length;
  return new Promise((resolve, reject) => {
    checkUploadRules(files, isMultiple).then(() => {
      files.forEach((file) => {
        compressFileToDataURL(file).then((imageData) => {
          result.push(imageData);
          if (result.length === fileLength) {
            resolve(result);
            target.value = "";
          }
        });
      });
    }).catch((err) => {
      reject(err);
    });
  });
};
export { ImageUploadErrorCodeEnum, base64ToFile, base64toBlob, compressCanvesToFile, compressFile, compressFileToDataURL, compressUploader, getImageData, getOrientation, urlToBase64 };
