/** 本地存储类型 */
export type LocalStoreType = 'localStorage' | 'sessionStorage';
/** 存储过期时间戳key */
export declare const LOCAL_STORAGE_OVERTIME_KEY = "_overtime_";
export declare const LOCAL_STORAGE_DATA_KEY = "_data_";
declare class StorageUtils {
    /** 缓存有效时间 小时 */
    private static _CACHE_EFFECTIVE_LIMIT_HOUR;
    /**
     * 保存到本地
     * @param storeKey
     * @param value
     * @param type
     */
    static setItem(storeKey: string, value: any, type?: LocalStoreType, cacheEffectiveHour?: number): void;
    /**
     * 获取本地存储
     * @param storeKey
     * @param type
     * @returns
     */
    static getItem(storeKey: string, type?: LocalStoreType, needTime?: boolean): any;
    /**
     * 设置hash对象缓存
     * @param storeKey
     * @param hashKey
     * @param value
     * @param type
     * @example
     *  StorageUtils.setHashItem('hashObject', 'hashKey1', 'value1'); >>> hashObject: {hashKey1: 'value1'}
     *  StorageUtils.setHashItem('hashObject', 'hashKey2', 'value'); >>> hashObject: {hashKey1: 'value1', hashKey2: 'value2'}
     */
    static setHashItem(storeKey: string, hashKey: string, value: any, type?: LocalStoreType): void;
    /**
     * 获取hash对象缓存
     * @param storeKey
     * @param hashKey
     * @param type
     */
    static getHashItem(storeKey: string, hashKey: string, type?: LocalStoreType): any;
    /**
     * 删除
     * @param key
     * @param type
     */
    static removeItem(storeKey: string, type?: LocalStoreType): void;
    /**
     * 清空
     * @param type
     */
    static clear(type?: LocalStoreType): void;
    /**
     * 缓存数量
     * @param type
     * @returns
     */
    static size(type?: LocalStoreType): number;
    static key(index: number, type?: LocalStoreType): string;
    /**
     * 是否支持本地缓存
     * @param type
     * @returns
     */
    static isSupport(type?: LocalStoreType): boolean;
    private static _getStorage;
}
export { StorageUtils };
