import { WechatSdk } from './sdk';
interface GetWechatShareConfigResType {
    signature: string;
    appId: string;
    noncestr: string;
    timestamp: string;
}
interface WechatJsonType extends Pick<GetWechatShareConfigResType, 'signature' | 'timestamp'> {
    nonceStr?: string;
    nonce: string;
    ticket: string;
}
interface ShareConfigType {
    title?: string;
    desc?: string;
    link?: string;
    imgUrl?: string;
}
export declare const wechatJsonHandler: (data: string) => void;
export declare class WechatUtils {
    static entryUrl: string;
    /**
     * 需要授权的API
     * TODO:  是否需要使用那么多
     */
    private static WECHAT_API_LIST;
    /** 最大重试次数 */
    private static MAX_RETRY_TIME;
    /** 重试间隔 */
    private static RETRY_INTERVAL;
    /** 微信配置信息 */
    private static WECHAT_SINGE_CONFIG;
    /** 微信签名和加密 */
    private static _wechatJson;
    /** 分享内容 */
    private static _shareConfig;
    /** 是否在微信中 */
    private static _isInWechat;
    /** 是否初始化成功 */
    private static _isInitSuccess;
    /** 重试次数 */
    private static _retryTime;
    /** 重试定时器 */
    private static _retryTimer;
    /** 微信配置 */
    private static get config();
    /** 是否完成微信签名初始化 */
    private static get _isFinishGetSignature();
    /** 获取微信执行环境 */
    static get wechatEnv(): {
        isWechat: boolean;
        isMiniprogram: boolean;
    };
    /** 初始化微信配置 */
    static init(): void;
    /** 配置微信分享 */
    static initShareConfig(config?: ShareConfigType, callback?: () => void): void;
    /** 存储获取的微信签名信息 */
    static setWechatJson(data: WechatJsonType): void;
    /**
     * 初始化微信配置
     */
    static initWechat(callback?: () => void): Promise<unknown>;
    /** 获取微信类型 */
    static getWechatAppType(): string;
    /**
     * JSONP 获取微信签名
     * @returns
     */
    private static _getSignatureByJsonp;
}
export { WechatSdk, };
