declare type ImageFit = 'contain' | 'cover' | 'fill' | 'none' | 'scale-down';
declare type Interceptor = (...args: any[]) => Promise<boolean> | boolean;
declare type UploaderFileListItem = {
    url?: string;
    file?: File;
    content?: string;
    isImage?: boolean;
    status?: '' | 'uploading' | 'done' | 'failed';
    message?: string;
    imageFit?: ImageFit;
    deletable?: boolean;
    previewSize?: number | string;
    beforeDelete?: Interceptor;
};
/** 图片上传错误 */
export declare enum ImageUploadErrorCodeEnum {
    /** 不存在图片 */
    none = 0,
    /** 文件类型不支持 */
    unSupportType = 1,
    /** 仅支持单张照片 */
    onlyOne = 2
}
export interface CompressFileType {
    dataURL: string;
    compressFile: Blob;
    fileName: string;
    fileType: string;
}
export declare const base64toBlob: (dataurl: string) => Blob;
/**
* 图片链接转Base64
* @param url
* @returns
*/
export declare const urlToBase64: (url: string) => Promise<string>;
/**
 * base64转File
 * @param base64Data
 * @param imgName
 * @returns
 */
export declare const base64ToFile: (base64Data: string, imgName: string) => File | null;
/**
 * 获取图片的旋转方向
 * 兼容ios低版本
 * @param file
 * @returns
 */
export declare const getOrientation: (file: File) => Promise<number | undefined>;
/**
 * 压缩图片
 * @param file
 * @param size
 */
export declare const compressFileToDataURL: (file: File, size?: number) => Promise<CompressFileType>;
/**
 * 压缩图片
 * @param file
 * @param size
 */
export declare const compressFile: (file: File, size?: number) => Promise<File>;
/**
 * canvas图片
 * @param file
 * @param size
 */
export declare const compressCanvesToFile: (canvasEle: HTMLCanvasElement, filename?: string, size?: number) => Promise<File>;
export declare const compressUploader: (items: UploaderFileListItem | UploaderFileListItem[]) => Promise<CompressFileType[]>;
/**
 * 获取图片
 * @param e
 * @param isMultiple
 * @returns
 */
export declare const getImageData: (e: InputEvent, isMultiple?: boolean) => Promise<CompressFileType[]>;
export {};
