/** 个人证件编码 */
export declare enum CertificateTypeCodeEnum {
    /** 身份证 */
    idCard = "01",
    /** 护照 */
    passport = "02",
    /** 军人证 */
    armypass = "03",
    /** 港澳通行证 */
    hkOrMacaoPermit = "04",
    /** 驾驶证 */
    drivingLicense = "05",
    /** 港澳回乡证或台胞证 */
    HMTidCard = "06",
    /** 临时身份证 */
    icCard = "07",
    /** 外国人永久居留身份证 */
    foreignerRermanentIdCard = "08",
    /** 港澳居民身份证 */
    hkOrMacaoIdCard = "09",
    /** 台湾通行证 */
    taiwan = "10",
    /** 户口本证件类型 */
    houseHoldRegister = "11",
    /** 组织机构代码 */
    organizingCode = "11",
    /** 工商执照注册号 */
    businessLicense = "12",
    /** 统一社会信用代码 */
    unifySocialCreditCode = "13",
    /** 其他 */
    other = "99"
}
/** 团体证件编码 */
export declare enum GroupCertificateTypeCodeEnum {
    /** 组织机构代码 */
    organizingCode = "g01",
    /** 税务登记证 */
    taxationCode = "g02",
    /** 统一社会信用代码(团) */
    xwUnifySocialCreditCode = "g03",
    /** 营业执照编码 */
    businessLicenseCode = "g04",
    /** 统一社会信用代码 */
    unifySocialCreditCode = "g05"
}
/**
 * 证件号码验证
 */
declare class CertificateNoValidator {
    /**
     * 证件号码验证
     * @param certificateNo string
     * @param type srting
     * @return string
     */
    static validate(certificateNo: string, type: string): string;
    /**
     * 身份证验证错误提示
     * @param idCard
     * @return string
     */
    private static getIdCard18Error;
    /**
     * 港澳居民身份证验证错误提示
     * @param value
     * @return string
     */
    private static getHkOrMacaoIdCardError;
    /**
     * 护照验证错误提示
     * 请输入长度8位或9位的字符,允许录入大写字母和阿拉伯数字组合、或纯数字
     * @param value string
     * @return string
     */
    private static getIPassPortIdError;
    /**
     * 军人证验证错误提示
     * @param value string
     * @return string
     */
    private static getIArmypassError;
    /**
     * 获取港澳回乡证或台胞证的校验规则错误提示
     * （台胞证）为8位字符，且只允许为阿拉伯数字；
     * （港澳回乡证）H或M+ 8至11位数字；其中，香港居民为H开头 + 8至11位数字；澳门居民为M+ 8至11位数字。
     * @param value string
     * @returns string
     */
    private static getIHMTidCardError;
    /**
     * 获取统一社会信用代码由18位大写字母 、数字组成错误提示
     * @param value string
     * @return string
     */
    private static getUnifySocialCreditCodeError;
    /**
     * 获取组织机构代码错误提示
     * @param value
     * @return string
     */
    private static getOrganizingCodeError;
    /**
     * 获取税务登记证错误提示
     * @param taxationCode
     * @return string
     */
    private static getTaxationCodeError;
    /**
     * 获取营业执照错误提示
     * @param value string
     * @reurn string
     */
    private static getBusinessLicenseCodeError;
    /** 是否正确日期 */
    private static isCorrectDate;
    /**
     * 是否正确的证件号码
     * @param cardId
     */
    private static isCorrectCard;
    /**
     * 是否组织编码
     * @param value
     * @param options
     */
    private static isOrganizingCode;
}
export default CertificateNoValidator;
