/**
 * 字符串验证
 */
declare class StringValidator {
    /**
     * 不能为'不详','不祥','未知','不知道'
     * @param value string
     * @string string
     */
    static illegaString(value: string): string;
    /**
     * 只能录入中文和符号"·"
     * @param value string
     * @string string
     */
    static illegaString1(value: string): string;
    /**
     * 只能录入中文、字母、空格、符号"·"
     * @param value string
     * @string string
     */
    static illegaString2(value: string): string;
    /**
     * 允许录入的规则组合：纯大写字母、大写字母加上空格、纯中文、中文加上符号'·'
     * @param value string
     * @string string
     */
    static illegaString3(value: string): string;
    /**
     * 只能录入中文、大写字母
     * @param value string
     * @string string
     */
    static illegaString4(value: string): string;
    /**
     * 不能出现“？”,“*”,“★”,“、”,“，”
     * @param value
     * @returns
     */
    static illegaString5(value: string): string;
    /**
     * 不能出现连续·
     * @param value string
     * @string string
     */
    static illegaStringSymbol(value: string): string;
    /**
     * 首尾不能出现·
     * @param value string
     * @string string
     */
    static illegaStringSymbol2(value: string): string;
    /**
     * 信息中部不能出现连续空格
     * @param value string
     * @string string
     */
    static illegaStringSymbol3(value: string): string;
    /**
     * 除末尾脱敏“*”号外不能出现“*”
     * @param value string
     * @string string
     */
    static illegaStringSymbol4(value: string): string;
    /**
     * 录入范围为最少${minLength = 2}位汉字，且不超过${maxLength = 150}位字符
     * @param value
     * @param options
     */
    static illegaChineseLength(value: string, options?: {
        maxLength?: number;
        minLength?: number;
        errorTips?: string;
    }): string;
    /**
   * @msg: 不超过20位字母或数字
   * @param value string
   * @return
   */
    static illegaStringLength(value: string): string;
    /**
      * @msg: 长度不超过
     * @param value string
     * @param maxLen number
     * @return
     */
    static illegaStringMaxLength(value: string, maxLen: number): string;
    /**
     * 只能为字母
     * @param value
     * @returns
     */
    static alpha(value: string): string;
    /**
     * 名称2
     */
    static ruleName2(value: string): string;
    /**
     * 只能录入中文、大写字母(包含生僻字)
     * @param value
     * @returns
     */
    static ruleRareWords(value: string): string;
}
export default StringValidator;
